pub struct WebSocketRelayEventOutput {
pub messages: Vec<WebSocketRelayMessage>,
pub close: Option<WebSocketRelayClose>,
pub extensions: Extensions,
}Expand description
Output for middleware used by WebSocketRelayEventService.
Fields
messages: Vec<WebSocketRelayMessage>Zero or more data messages to send to the opposite WebSocket connection.
Ping, pong and raw frames cannot be produced through this API.
close: Option<WebSocketRelayClose>Optionally request coordinated shutdown of both WebSocket connections. Messages are sent before a valid requested shutdown starts.
When serving WebSocketRelayEvent::Close, shutdown has already been
initiated by the relay and both messages and close are ignored.
extensions: ExtensionsPer-direction relay state. Middleware should normally return the input store (or a derivative of it); replacing it with a fresh store also replaces its connection-extension parent link.