pub struct WebSocketRelayOutput {
pub messages: Vec<WebSocketRelayMessage>,
pub extensions: Extensions,
}Expand description
Most typically used as Output
for users of WebSocketRelayService.
Fields
messages: Vec<WebSocketRelayMessage>0 or more messages, providing the ability to drop messages first and return buffered messages later. Messages are sent to the opposite WebSocket connection.
extensions: ExtensionsPer-direction relay state. Middleware should normally return the input store (or a derivative of it); replacing it with a fresh store also replaces its connection-extension parent link.