pub enum ProtocolError {
Show 19 variants
Utf8(BoxError),
Io(Error),
InvalidOpcode(u8),
InvalidCloseSequence,
MessageTooLong {
size: usize,
max_size: usize,
},
UnmaskedFrameFromClient,
WriteBufferFull(Message),
SendAfterClosing,
ReceivedAfterClosing,
NonZeroReservedBits,
MaskedFrameFromServer,
FragmentedControlFrame,
ControlFrameTooBig,
UnknownControlFrameType(u8),
ResetWithoutClosingHandshake,
UnexpectedContinueFrame,
ExpectedFragment(OpCodeData),
UnknownDataFrameType(u8),
DeflateError(BoxError),
}Expand description
Indicates the specific type/cause of a protocol error.
Variants
Utf8(BoxError)
a utf-8 decode error
Io(Error)
Input-output error.
These are generally errors with the underlying connection and you should probably consider them fatal.
InvalidOpcode(u8)
Encountered an invalid opcode.
InvalidCloseSequence
The payload for the closing frame is invalid.
MessageTooLong
Received header is too long.
Message is bigger than the maximum allowed size.
Fields
UnmaskedFrameFromClient
The server must close the connection when an unmasked frame is received.
WriteBufferFull(Message)
Message write buffer is full.
SendAfterClosing
Not allowed to send after having sent a closing frame.
ReceivedAfterClosing
Remote sent data after sending a closing frame.
NonZeroReservedBits
Reserved bits in frame header are non-zero.
MaskedFrameFromServer
The client must close the connection when a masked frame is received.
FragmentedControlFrame
Control frames must not be fragmented.
ControlFrameTooBig
Control frames must have a payload of 125 bytes or less.
UnknownControlFrameType(u8)
Type of control frame not recognised.
ResetWithoutClosingHandshake
Connection closed without performing the closing handshake.
UnexpectedContinueFrame
Received a continue frame despite there being nothing to continue.
ExpectedFragment(OpCodeData)
Received data while waiting for more fragments.
UnknownDataFrameType(u8)
Type of data frame not recognised.
DeflateError(BoxError)
Error while applying the deflate extension
Implementations
Sourceimpl ProtocolError
impl ProtocolError
Sourcepub fn is_connection_error(&self) -> bool
pub fn is_connection_error(&self) -> bool
Check if the error is a connection error, in which case the error can be ignored.