WebSocket

Struct WebSocket 

pub struct WebSocket<Stream> { /* private fields */ }
WebSocket input-output stream.

This is THE structure you want to create to be able to speak the WebSocket protocol. It may be created by calling connect, accept or client functions.

Use WebSocket::read, WebSocket::send to received and send messages.

Implementations

Source

impl<Stream> WebSocket<Stream>

pub fn from_raw_socket( stream: Stream, role: Role, config: Option<WebSocketConfig>, ) -> Self

Convert a raw socket into a WebSocket without performing a handshake.

Panics

Panics if config is invalid e.g. max_write_buffer_size <= write_buffer_size.

pub fn from_partially_read( stream: Stream, part: Vec<u8>, role: Role, config: Option<WebSocketConfig>, ) -> Self

Convert a raw socket into a WebSocket without performing a handshake.

Panics

Panics if config is invalid e.g. max_write_buffer_size <= write_buffer_size.

pub fn get_ref(&self) -> &Stream

Returns a shared reference to the inner stream.

pub fn get_mut(&mut self) -> &mut Stream

Returns a mutable reference to the inner stream.

pub fn set_config(&mut self, set_func: impl FnOnce(&mut WebSocketConfig))

Change the configuration.

Panics

Panics if config is invalid e.g. max_write_buffer_size <= write_buffer_size.

pub fn get_config(&self) -> &WebSocketConfig

Read the configuration.

pub fn can_read(&self) -> bool

Check if it is possible to read messages.

Reading is impossible after receiving Message::Close. It is still possible after sending close frame since the peer still may send some data before confirming close.

pub fn can_write(&self) -> bool

Check if it is possible to write messages.

Writing gets impossible immediately after sending or receiving Message::Close.

Source

impl<Stream: Read + Write> WebSocket<Stream>

pub fn read(&mut self) -> Result<Message, ProtocolError>

Read a message from stream, if possible.

This will also queue responses to ping and close messages. These responses will be written and flushed on the next call to read, write or flush.

Closing the connection

When the remote endpoint decides to close the connection this will return the close message with an optional close frame.

You should continue calling read, write or flush to drive the reply to the close frame until [Error::ConnectionClosed] is returned. Once that happens it is safe to drop the underlying connection.

pub fn send(&mut self, message: Message) -> Result<(), ProtocolError>

Writes and immediately flushes a message. Equivalent to calling write then flush.

pub fn write(&mut self, message: Message) -> Result<(), ProtocolError>

Write a message to the provided stream, if possible.

A subsequent call should be made to flush to flush writes.

In the event of stream write failure the message frame will be stored in the write buffer and will try again on the next call to write or flush.

If the write buffer would exceed the configured WebSocketConfig::max_write_buffer_size Err(WriteBufferFull(msg_frame)) is returned.

This call will generally not flush. However, if there are queued automatic messages they will be written and eagerly flushed.

For example, upon receiving ping messages this crate queues pong replies automatically. The next call to read, write or flush will write & flush the pong reply. This means you should not respond to ping frames manually.

You can however send pong frames manually in order to indicate a unidirectional heartbeat as described in RFC 6455. Note that if read returns a ping, you should flush before passing a custom pong to write, otherwise the automatic queued response to the ping will not be sent as it will be replaced by your custom pong message.

Errors
  • If the WebSocket’s write buffer is full, [Error::WriteBufferFull] will be returned along with the equivalent passed message frame.
  • If the connection is closed and should be dropped, this will return [Error::ConnectionClosed].
  • If you try again after [Error::ConnectionClosed] was returned either from here or from read, [Error::AlreadyClosed] will be returned. This indicates a program error on your part.
  • [Error::Io] is returned if the underlying connection returns an error (consider these fatal except for WouldBlock).
  • [Error::Capacity] if your message size is bigger than the configured max message size.
pub fn flush(&mut self) -> Result<(), ProtocolError>

Flush writes.

Ensures all messages previously passed to write and automatic queued pong responses are written & flushed into the underlying stream.

pub fn close(&mut self, code: Option<CloseFrame>) -> Result<(), ProtocolError>

Close the connection.

This function guarantees that the close frame will be queued. There is no need to call it again. Calling this function is the same as calling write(Message::Close(..)).

After queuing the close frame you should continue calling read or flush to drive the close handshake to completion.

The websocket RFC defines that the underlying connection should be closed by the server. This crate takes care of this asymmetry for you.

When the close handshake is finished (we have both sent and received a close message), read or flush will return [Error::ConnectionClosed] if this endpoint is the server.

If this endpoint is a client, [Error::ConnectionClosed] will only be returned after the server has closed the underlying connection.

It is thus safe to drop the underlying connection as soon as [Error::ConnectionClosed] is returned from read or flush.