pub enum Message {
Text(Utf8Bytes),
Binary(Bytes),
Ping(Bytes),
Pong(Bytes),
Close(Option<CloseFrame>),
Frame(Frame),
}Expand description
An enum representing the various forms of a WebSocket message.
Variants
Text(Utf8Bytes)
A text WebSocket message
Binary(Bytes)
A binary WebSocket message
Ping(Bytes)
A ping message with the specified payload
The payload here must have a length less than 125 bytes
Pong(Bytes)
A pong message with the specified payload
The payload here must have a length less than 125 bytes
Close(Option<CloseFrame>)
A close message with the optional close frame.
Frame(Frame)
Raw frame. Note, that you’re not going to get this value while reading the message.
Implementations
Sourceimpl Message
impl Message
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the WebSocket message has no content. For example, if the other side of the connection sent an empty string.
Sourcepub fn into_text(self) -> Result<Utf8Bytes, ProtocolError>
pub fn into_text(self) -> Result<Utf8Bytes, ProtocolError>
Attempt to consume the WebSocket message and convert it to a String.
Sourcepub fn to_text(&self) -> Result<&str, ProtocolError>
pub fn to_text(&self) -> Result<&str, ProtocolError>
Attempt to get a &str from the WebSocket message, this will try to convert binary data to utf8.